#' @title Launch shiny app
#' @description Launches shiny app for visualizing distributions.
#' @examples
#' \dontrun{
#' vdist_launch_app ()
#' }
#' @export
#'
vdist_launch_app  <- function() {
	
	xplorerr::app_vistributions()
}
 